=== modified file 'plugin/mysql_unix_socket_protocol/protocol.cc'
--- plugin/mysql_unix_socket_protocol/protocol.cc	2010-11-19 04:19:50 +0000
+++ plugin/mysql_unix_socket_protocol/protocol.cc	2010-11-18 07:03:09 +0000
@@ -30,6 +30,7 @@
 #include <algorithm>
 #include <iostream>
 #include <boost/program_options.hpp>
+#include <boost/filesystem.hpp>
 #include <drizzled/module/option_map.h>
 
 #include <sys/un.h>
@@ -38,9 +39,8 @@
 
 #define DRIZZLE_UNIX_SOCKET_PATH "/tmp/mysql.socket"
 
-static std::string unix_socket_path(DRIZZLE_UNIX_SOCKET_PATH);
-
 namespace po= boost::program_options;
+namespace fs= boost::filesystem;
 using namespace drizzled;
 using namespace std;
 
@@ -49,11 +49,12 @@
 
 Protocol::~Protocol()
 {
+  fs::remove(unix_socket_path);
 }
 
 const char* Protocol::getHost(void) const
 {
-  return DRIZZLE_UNIX_SOCKET_PATH;
+  return unix_socket_path.file_string().c_str();
 }
 
 in_port_t Protocol::getPort(void) const
@@ -65,13 +66,21 @@
 {  
   const module::option_map &vm= context.getOptions();
 
-  if (vm.count("path"))
-  {
-    unix_socket_path.clear();
-    unix_socket_path.append(vm["path"].as<string>());
-  }
-
-  context.add(new Protocol("mysql_unix_socket_protocol", true));
+  fs::path uds_path(vm["path"].as<fs::path>());
+  if (not fs::exists(uds_path))
+  {
+    context.add(new Protocol("mysql_unix_socket_protocol",
+                             true,
+                             uds_path));
+    context.registerVariable(new sys_var_fs_path("path", uds_path));
+  }
+  else
+  {
+    cerr << uds_path << _(" exists already. Do you have another Drizzle or "
+                          "MySQL running? Or perhaps the file is stale and "
+                          "should be removed?") << std::endl;
+    return 1;
+  }
 
   return 0;
 }
@@ -91,39 +100,39 @@
   memset(&servAddr, 0, sizeof(servAddr));
 
   servAddr.sun_family= AF_UNIX;
-  strcpy(servAddr.sun_path, unix_socket_path.c_str());
+  strcpy(servAddr.sun_path, unix_socket_path.file_string().c_str());
 
   // In case we restart and find something in our way we move it aside and
   // then attempt to remove it.
   {
-    std::string move_file(unix_socket_path);
-    move_file.append(".old");
-    std::rename(unix_socket_path.c_str(), move_file.c_str());
-    unlink(move_file.c_str());
+    fs::path move_file(unix_socket_path.file_string() + ".old");
+    fs::rename(unix_socket_path, move_file);
+    unlink(move_file.file_string().c_str());
   }
 
 
   int arg= 1;
 
   (void) setsockopt(unix_sock, SOL_SOCKET, SO_REUSEADDR, (char*)&arg, sizeof(arg));
+  unlink(unix_socket_path.file_string().c_str());
 
   addrlen= sizeof(servAddr);
   if (::bind(unix_sock, reinterpret_cast<sockaddr *>(&servAddr), addrlen) < 0)
   { 
-    std::cerr << "Can't start server : Bind on unix socket\n";
-    std::cerr << "Do you already have another of drizzled or mysqld running on socket: " << unix_socket_path << "?\n";
-    std::cerr << "Can't start server : UNIX Socket";
+    std::cerr << "Can't start server : Bind on unix socket." << std::endl;
+    std::cerr << "Do you already have another of drizzled or mysqld running on socket: " << unix_socket_path << "?" << std::endl;
+    std::cerr << "Can't start server : UNIX Socket" << std::endl;
 
     return false;
   }
 
-  if (listen(unix_sock,(int) 1000) < 0)
+  if (listen(unix_sock, (int) 1000) < 0)
   {
     std::cerr << "listen() on Unix socket failed with error " << errno << "\n";
   }
   else
   {
-    std::cerr << "Listening on " << unix_socket_path.c_str() << "\n";
+    std::cerr << "Listening on " << unix_socket_path << "\n";
   }
   (void) unlink(unix_socket_path.c_str());
 
@@ -136,14 +145,10 @@
 static void init_options(drizzled::module::option_context &context)
 {
   context("path",
-          po::value<string>()->default_value(unix_socket_path),
+          po::value<fs::path>()->default_value(DRIZZLE_UNIX_SOCKET_PATH),
           N_("Path used for MySQL UNIX Socket Protocol."));
 }
 
-static drizzle_sys_var* sys_variables[]= {
-  NULL
-};
-
 } /* namespace mysql_unix_socket_protocol */
 
-DRIZZLE_PLUGIN(mysql_unix_socket_protocol::init, mysql_unix_socket_protocol::sys_variables, mysql_unix_socket_protocol::init_options);
+DRIZZLE_PLUGIN(mysql_unix_socket_protocol::init, NULL, mysql_unix_socket_protocol::init_options);

=== modified file 'plugin/mysql_unix_socket_protocol/protocol.h'
--- plugin/mysql_unix_socket_protocol/protocol.h	2010-10-28 14:56:34 +0000
+++ plugin/mysql_unix_socket_protocol/protocol.h	2010-11-18 07:03:09 +0000
@@ -27,6 +27,8 @@
 #include <drizzled/atomics.h>
 #include "drizzled/plugin/table_function.h"
 
+#include <boost/filesystem.hpp>
+
 #include "plugin/mysql_protocol/mysql_protocol.h"
 
 namespace mysql_unix_socket_protocol
@@ -34,9 +36,13 @@
 
 class Protocol: public ListenMySQLProtocol
 {
+  const boost::filesystem::path unix_socket_path;
 public:
-  Protocol(std::string name_arg, bool using_mysql41_protocol_arg):
-    ListenMySQLProtocol(name_arg, using_mysql41_protocol_arg)
+  Protocol(std::string name_arg,
+           bool using_mysql41_protocol_arg,
+           const boost::filesystem::path &unix_socket_path_arg) :
+    ListenMySQLProtocol(name_arg, using_mysql41_protocol_arg),
+    unix_socket_path(unix_socket_path_arg)
   { }
 
   ~Protocol();

=== modified file 'tests/lib/dtr_process.pl'
--- tests/lib/dtr_process.pl	2010-11-10 15:35:05 +0000
+++ tests/lib/dtr_process.pl	2010-11-18 07:03:09 +0000
@@ -356,7 +356,7 @@
     dtr_debug("  - drizzled " .
               "(pid: $srv->{pid}; " .
               "pid file: '$srv->{path_pid}'; " .
-              "socket: '$srv->{path_sock}'; ".
+              "socket: '$srv->{sockfile}'; ".
               "port: $srv->{port})");
 
     my $pid= dtr_server_shutdown($srv);
@@ -367,7 +367,7 @@
     push(@kill_pids,{
 		     pid      => $srv->{'pid'},
 		     pidfile  => $srv->{'path_pid'},
-		     sockfile => $srv->{'path_sock'},
+		     sockfile => $srv->{'sockfile'},
 		     port     => $srv->{'port'},
 		    });
     $srv->{'pid'}= 0; # Assume we are done with it
@@ -590,6 +590,11 @@
       {
         dtr_error("can't remove $srv->{'pidfile'}");
       }
+      if ( -f $srv->{'sockfile'} and ! unlink($srv->{'sockfile'}) and
+           -f $srv->{'sockfile'} )
+      {
+        dtr_error("can't remove $srv->{'sockfile'}");
+      }
     }
   }
 
@@ -608,6 +613,10 @@
     my $errors= 0;
     foreach my $srv ( @$spec )
     {
+      if ( $srv->{'sockfile'} )
+      {
+        unlink($srv->{'sockfile'});
+      }
       if ( $srv->{'pid'} )
       {
 	# Server has been hard killed, clean it's resources
@@ -682,11 +691,6 @@
   dtr_add_arg($args, "--password=");
   dtr_add_arg($args, "--silent");
 
-  if ( -e $srv->{'path_sock'} )
-  {
-    dtr_add_arg($args, "--socket=%s", $srv->{'path_sock'});
-  }
-
   if ( $srv->{'port'} )
   {
     dtr_add_arg($args, "--port=%s", $srv->{'port'});

=== modified file 'tests/test-run.pl'
--- tests/test-run.pl	2010-11-07 05:10:46 +0000
+++ tests/test-run.pl	2010-11-18 07:03:09 +0000
@@ -942,17 +942,6 @@
     }
   }
 
-  # On QNX, /tmp/dir/master.sock and /tmp/dir//master.sock seem to be
-  # considered different, so avoid the extra slash (/) in the socket
-  # paths.
-  my $sockdir = $opt_tmpdir;
-  $sockdir =~ s|/+$||;
-
-  # On some operating systems, there is a limit to the length of a
-  # UNIX domain socket's path far below PATH_MAX, so try to avoid long
-  # socket path names.
-  $sockdir = tempdir(CLEANUP => 0) if ( length($sockdir) >= 70 );
-
   $master->[0]=
   {
    pid            => 0,
@@ -961,7 +950,7 @@
    path_myddir    => "$opt_vardir/master-data",
    path_myerr     => "$opt_vardir/log/master.err",
    path_pid       => "$opt_vardir/run/master.pid",
-   path_sock      => "$sockdir/master.sock",
+   path_sock      => "$opt_vardir/master.sock",
    port           =>  $opt_master_myport,
    secondary_port =>  $opt_master_myport + $secondary_port_offset,
    start_timeout  =>  400, # enough time create innodb tables
@@ -977,7 +966,7 @@
    path_myddir    => "$opt_vardir/master1-data",
    path_myerr     => "$opt_vardir/log/master1.err",
    path_pid       => "$opt_vardir/run/master1.pid",
-   path_sock      => "$sockdir/master1.sock",
+   path_sock      => "$opt_vardir/master1.sock",
    port           => $opt_master_myport + 1,
    secondary_port => $opt_master_myport + 1 + $secondary_port_offset,
    start_timeout  => 400, # enough time create innodb tables
@@ -993,7 +982,7 @@
    path_myddir    => "$opt_vardir/slave-data",
    path_myerr     => "$opt_vardir/log/slave.err",
    path_pid       => "$opt_vardir/run/slave.pid",
-   path_sock      => "$sockdir/slave.sock",
+   path_sock      => "$opt_vardir/slave.sock",
    port           => $opt_slave_myport,
    secondary_port => $opt_slave_myport + $secondary_port_offset,
    start_timeout  => 400,
@@ -1009,7 +998,7 @@
    path_myddir    => "$opt_vardir/slave1-data",
    path_myerr     => "$opt_vardir/log/slave1.err",
    path_pid       => "$opt_vardir/run/slave1.pid",
-   path_sock      => "$sockdir/slave1.sock",
+   path_sock      => "$opt_vardir/slave1.sock",
    port           => $opt_slave_myport + 1,
    secondary_port => $opt_slave_myport + 1 + $secondary_port_offset,
    start_timeout  => 300,
@@ -1025,7 +1014,7 @@
    path_myddir    => "$opt_vardir/slave2-data",
    path_myerr     => "$opt_vardir/log/slave2.err",
    path_pid       => "$opt_vardir/run/slave2.pid",
-   path_sock      => "$sockdir/slave2.sock",
+   path_sock      => "$opt_vardir/slave2.sock",
    port           => $opt_slave_myport + 2,
    secondary_port => $opt_slave_myport + 2 + $secondary_port_offset,
    start_timeout  => 300,
@@ -2533,6 +2522,9 @@
   dtr_add_arg($args, "%s--datadir=%s", $prefix,
 	      $drizzled->{'path_myddir'});
 
+  dtr_add_arg($args, "%s--mysql-unix-socket-protocol.path=%s", $prefix,
+              $drizzled->{'path_sock'});
+
   # Check if "extra_opt" contains --skip-log-bin
   if ( $drizzled->{'type'} eq 'master' )
   {

